from nwon_baseline.file_helper.file import file_extension_from_path as file_extension_from_path, file_extension_from_url as file_extension_from_url, get_file_as_binary as get_file_as_binary, get_file_object as get_file_object, handle_uploaded_file as handle_uploaded_file, read_file_as_binary as read_file_as_binary, read_file_content as read_file_content
from nwon_baseline.file_helper.filename_from_url import filename_from_url as filename_from_url



from enum import Enum
from typing import List, Type, TypeVar

T = TypeVar('T', bound=Enum)

def enum_value_list(enum_class: Type[T]) -> List[str]: ...
def enum_value_list_as_string(enum_class: Type[T], separator: str = ...) -> str: ...



from typing import List, Optional

def file_names_in_directory(path_name: str): ...
def file_paths_in_directory(path_name: str, filter_extensions: Optional[List[str]] = ...) -> List[str]: ...
def directory_names_in_directory(path_name: str): ...
def directory_paths_in_directory(path_name: str): ...
def get_latest_file_in_directory(path: str): ...
def paths_in_directory(directory: str) -> List[str]: ...



from typing import Iterable, Union

def unique_list(list_to_check: Union[Iterable[Union[str, int, float, bool, bytes]], Iterable[str], Iterable[int], Iterable[float], Iterable[bool], Iterable[bytes]]): ...



import sys
from typing import SupportsComplex, SupportsFloat
from typing_extensions import TypeAlias

if sys.version_info >= (3, 8):
    from typing import SupportsIndex

e: float
pi: float
inf: float
infj: complex
nan: float
nanj: complex
tau: float

if sys.version_info >= (3, 8):
    _C: TypeAlias = SupportsFloat | SupportsComplex | SupportsIndex | complex
else:
    _C: TypeAlias = SupportsFloat | SupportsComplex | complex

def acos(__z: _C) -> complex: ...
def acosh(__z: _C) -> complex: ...
def asin(__z: _C) -> complex: ...
def asinh(__z: _C) -> complex: ...
def atan(__z: _C) -> complex: ...
def atanh(__z: _C) -> complex: ...
def cos(__z: _C) -> complex: ...
def cosh(__z: _C) -> complex: ...
def exp(__z: _C) -> complex: ...
def isclose(a: _C, b: _C, *, rel_tol: SupportsFloat = 1e-09, abs_tol: SupportsFloat = 0.0) -> bool: ...
def isinf(__z: _C) -> bool: ...
def isnan(__z: _C) -> bool: ...
def log(__x: _C, __base: _C = ...) -> complex: ...
def log10(__z: _C) -> complex: ...
def phase(__z: _C) -> float: ...
def polar(__z: _C) -> tuple[float, float]: ...
def rect(__r: float, __phi: float) -> complex: ...
def sin(__z: _C) -> complex: ...
def sinh(__z: _C) -> complex: ...
def sqrt(__z: _C) -> complex: ...
def tan(__z: _C) -> complex: ...
def tanh(__z: _C) -> complex: ...
def isfinite(__z: _C) -> bool: ...



from nwon_baseline.shell_helper.execute_command import execute_command as execute_command, execute_command_and_print as execute_command_and_print
from nwon_baseline.shell_helper.get_environment_variable import get_environment_variable as get_environment_variable



from nwon_baseline.poetry.checking_version_argument import checking_version_argument as checking_version_argument
from nwon_baseline.poetry.package_version import update_package_version as update_package_version



from typing import List

def create_paths(paths: List[str]) -> None: ...
def copy_directory(source_directory: str, target_directory: str) -> None: ...
def clean_directory(directory: str, recursive: bool = ...): ...



from enum import IntEnum
from typing import ClassVar
from typing_extensions import Literal

from .ImageFile import ImageFile

MAGIC: bytes

class Format(IntEnum):
    DXT1: int
    UNCOMPRESSED: int

FORMAT_DXT1: Literal[Format.DXT1]
FORMAT_UNCOMPRESSED: Literal[Format.UNCOMPRESSED]

class FtexImageFile(ImageFile):
    format: ClassVar[Literal["FTEX"]]
    format_description: ClassVar[str]
    def load_seek(self, pos) -> None: ...



from nwon_baseline.typings import TerminalColors as TerminalColors, TerminalStyling as TerminalStyling

def print_with_color_and_style(text: str, color: TerminalColors, style: TerminalStyling) -> None: ...
def print_with_style(text: str, style: TerminalStyling) -> None: ...



from enum import Enum

class TerminalColors(Enum):
    Red: str
    Green: str
    Blue: str
    Cyan: str
    White: str
    Yellow: str
    Magenta: str
    Grey: str
    Black: str
    Default: str
    Warning: str
    Error: str
    Success: str

class TerminalStyling(Enum):
    Header: str
    EndCharacter: str
    Bold: str
    Underline: str



from nwon_baseline.typings import TerminalColors as TerminalColors

def print_red(text: str): ...
def print_green(text: str): ...
def print_blue(text: str): ...
def print_cyan(text: str): ...
def print_white(text: str): ...
def print_yellow(text: str): ...
def print_magenta(text: str): ...
def print_grey(text: str): ...
def print_black(text: str): ...
def print_default(text: str): ...
def print_warning(text: str): ...
def print_error(text: str): ...
def print_success(text: str): ...
def print_color(text: str, color: TerminalColors) -> None: ...
